import Vue from "vue";
import Vuex from "vuex";
import axios from "axios";

Vue.use(Vuex);

export default new Vuex.Store({
  state: {
    services: [],
    homePage: null,
    reviews: [],
  },
  mutations: {
    setServices(state, services) {
      state.services = services;
    },
    setCategoryExpanded(state, payload) {
      if (payload.category) {
        Vue.set(payload.category.attributes, "expanded", payload.value);
      } else {
        Vue.set(
          payload.service.attributes.categories.data[payload.index].attributes,
          "expanded",
          payload.value
        );
      }
    },
    setHomePage(state, payload) {
      state.homePage = payload;
    },
    setReviews(state, payload) {
        state.reviews = payload;
      },
  },
  actions: {
    async getServices(state) {
      return new Promise((resolve) => {
        if (!state.getters.isServicesEmpty) {
          resolve();
          return;
        }
        axios
          .get(`/V1/services?populate=*`)
          .then((response) => {
            state.commit("setServices", response.data.data);
          })
          .finally(() => {
            resolve();
          });
      });
    },
    async getHomePage(state) {
      return new Promise((resolve) => {
        if (!state.getters.isHomePageEmpty) {
          resolve();
          return;
        }
        axios
          .get(`/V1/home-page`)
          .then((response) => {
            state.commit("setHomePage", response.data.data.attributes);
          })
          .finally(() => {
            resolve();
          });
      });
    },
    async getReviews(state) {
        return new Promise((resolve) => {
          if (!state.getters.isReviewsEmpty) {
            resolve();
            return;
          }
          axios
            .get(`/V1/reviews`)
            .then((response) => {
              state.commit("setReviews", response.data.data);
            })
            .finally(() => {
              resolve();
            });
        });
      },
  },
  getters: {
    isServicesEmpty(state) {
      return state.services.length <= 0;
    },
    isHomePageEmpty(state) {
      return state.homePage ? false : true;
    },
    isReviewsEmpty(state) {
        return state.reviews.length <= 0;
      },
  },
});
